/***********************************************************

* Descriptive statistics tables  *

- Table 11 - Descriptive statistics pre- and post-reform 
- Table 12 - Descriptive statistics for all 5 groups of municipalities  

***********************************************************/


clear
set more off
use ../../Data/Final/Data_final.dta, replace

* Order variables *
order  Spese_corr_pc Spese_cc_pc Spese_prestiti_pc Spese_servizi_pc Entr_extra_pc /*  Balance sheet
*/ Entr_alienaz_pc Entr_prestiti_pc  Entr_servizi_pc Entr_trib_pc Entr_trasf_pc /*
*/ population surface  altitude density  /*  Geo
*/ term term_limited age male education   // Politics


* Label *
label var Spese_corr_pc "Current expenditures"
label var Spese_cc_pc "Investment expenditures"
label var Spese_prestiti_pc "Loans expenditures"
label var Spese_servizi_pc "Services expenditures"
label var Entr_alienaz_pc "Disposal of assets"
label var Entr_prestiti_pc "Loans revenues"
label var Entr_extra_pc "Non-tax revenues"
label var Entr_servizi_pc "Services revenues"
label var Entr_trib_pc "Tax revenues"
label var Entr_trasf_pc "Transfers revenues"
label var term_limited "Term limited"
label var term_counter "Experience (terms)"



*** Table 12 - Descriptive statistics pre- and post-reform ***

eststo clear

* Balance sheet *
estpost su Spese_corr_pc-Entr_trasf_pc if   (year >= 1999& year <=2007)
eststo A

estpost su Spese_corr_pc-Entr_trasf_pc if   (year >= 2008 & year <=2012)
eststo B

estpost su Spese_corr_pc-Entr_trasf_pc if   (year >= 1999& year <=2012)
eststo C


esttab A B C  using ../../Results/Tables/Table_11.tex, replace label /*
*/ mtitle("1999-2007" "2008-2012" "1999-2012") /*
*/ refcat(Spese_corr_pc "\textbf{Balance sheet expenditures}" Entr_extra_pc "\textbf{Balance sheet revenues}", nolabel)  /*
*/ f nogaps noobs nonum booktabs collabels(none) plain /*
*/ cells(mean(fmt(1)) sd(fmt(1) par ))  width(\hsize)  


* Geo *
estpost su population-density if   (year >= 1999& year <=2007)
eststo A

estpost su population-density if   (year >= 2008 & year <=2012)
eststo B

estpost su population-density if   (year >= 1999& year <=2012)
eststo C


esttab A B C  using  ../../Results/Tables/Table_11.tex, append  label /*
*/ refcat(population "\textbf{Geographic characteristics}" , nolabel)  /*
*/ f nogaps noobs nonum nomtitles booktabs collabels(none) plain /*
*/ cells(mean(fmt(1)) sd(fmt(1) par )) width(\hsize)  


* Political *
estpost su term-education if   (year >= 1999& year <=2007)
eststo A

estpost su term-education if   (year >= 2008 & year <=2012)
eststo B

estpost su term-education if   (year >= 1999& year <=2012)
eststo C


esttab A B C  using ../../Results/Tables/Table_11.tex, append nonum label /*
*/ cells(mean(fmt(2)) sd(fmt(2) par ))   /*
*/ f nogaps nonum nomtitles booktabs collabels(none) plain /*
*/ refcat(term "\textbf{Characteristics of the mayor}" , nolabel)  /*
*/ width(\hsize)  



*** Table 13 - Descriptive statistics for all groups of municipalities **** 

gen group_elections = 0

* Identify groups of municipalities: 1999-2004-2009 is the first, etc. *
forv i = 1999(1)2003 {
gen gr`i' = anno if anno == `i'
bys town: egen group_`i' = max(gr`i')
replace group_elections = group_`i' if  group_`i' !=. & group_elections == 0
}
*

drop if group_elections == 0  // A few mistakes/missings/new towns 
label var group_elections "Election group (1999-2003)"


eststo clear

* Balance sheet *

estpost tabstat Spese_corr_pc-Entr_trasf_pc if   group_elections == 1999,  stat(mean semean) columns(statistics)
eststo A

estpost tabstat Spese_corr_pc-Entr_trasf_pc if    group_elections == 2000,  stat(mean semean) columns(statistics)
eststo B

estpost tabstat Spese_corr_pc-Entr_trasf_pc if    group_elections == 2001,  stat(mean semean) columns(statistics)
eststo C

estpost tabstat Spese_corr_pc-Entr_trasf_pc if    group_elections == 2002,  stat(mean semean) columns(statistics)
eststo D

estpost tabstat Spese_corr_pc-Entr_trasf_pc if    group_elections == 2003,  stat(mean semean) columns(statistics)
eststo E


esttab A B C D E using ../../Results/Tables/Table_12.tex, replace label /*
*/ mtitle("1999" "2000" "2001" "2002" "2003")  /*
*/ refcat(Spese_corr_pc "\textbf{Balance sheet expenditures}" Entr_extra_pc "\textbf{Balance sheet revenues}", nolabel)  /*
*/ f nogaps noobs nonum booktabs collabels(none) plain /*
*/ cells(mean(fmt(1)) semean(fmt(1) par )) width(\hsize)   // Standard error in this table, not SD!


* Geo *

estpost tabstat population-density  if   group_elections == 1999 ,  stat(mean semean) columns(statistics)
eststo A

estpost tabstat population-density  if    group_elections == 2000 ,  stat(mean semean) columns(statistics)
eststo B

estpost tabstat population-density  if    group_elections == 2001 ,  stat(mean semean) columns(statistics)
eststo C

estpost tabstat population-density  if    group_elections == 2002 ,  stat(mean semean) columns(statistics)
eststo D

estpost tabstat population-density  if    group_elections == 2003 ,  stat(mean semean) columns(statistics)
eststo E


esttab A B C D E  using ../../Results/Tables/Table_12.tex, append  label /*
*/ refcat(population "\textbf{Geographic characteristics}" , nolabel)  /*
*/ f nogaps noobs nonum nomtitles booktabs collabels(none) plain /*
*/ cells(mean(fmt(1)) semean(fmt(1) par )) width(\hsize)   // Standard error in this table, not SD!


* Political *
estpost tabstat term-education  if   group_elections == 1999 ,  stat(mean semean) columns(statistics)
eststo A

estpost tabstat term-education  if    group_elections == 2000,  stat(mean semean) columns(statistics)
eststo B

estpost tabstat term-education  if    group_elections == 2001,  stat(mean semean) columns(statistics)
eststo C

estpost tabstat term-education  if    group_elections == 2002,  stat(mean semean) columns(statistics)
eststo D

estpost tabstat term-education  if    group_elections == 2003,  stat(mean semean) columns(statistics)
eststo E


esttab A B C D E using ../../Results/Tables/Table_12.tex, append nonum label /*
*/ f nogaps nonum nomtitles booktabs collabels(none) plain /*
*/ refcat(term "\textbf{Characteristics of the mayor}" , nolabel)  /*
*/ cells(mean(fmt(1)) semean(fmt(2) par )) width(\hsize)   // Standard error in this table, not SD!
