/****************************************************************************************

* Estimation - coefficient plots for some results in the paper *

* Figures 5, 6, 7 *

****************************************************************************************/

clear all
set more off

use ../../Data/Final/Data_final.dta, replace
do ../Auxiliary/Estimation_globals.do // Define global variables 


* Choose Palatino Fonts *
local graphfont "Palatino"
graph set eps fontface `graphfont'
graph set eps fontfaceserif `graphfont'
graph set eps  /*echo back preferences*/
 
graph set window fontface `graphfont'
graph set window fontfaceserif `graphfont'
graph set window /*echo back preferences*/


**  Figure 5 - Baseline main result ** 
areg  Spese_cc_pc $x1 $controls_panel $pol_controls i.year##i.region_code, cluster(id_towns) absorb(id_towns) 

mat M = e(b)
mat V = e(V)

matrix T = [-2,-1,0,1,2]

mat coeff = M[1,1..3]
mat coeff = coeff,0 , M[1,4]

mat coeff_post = M[1,5..7]
mat coeff_post = coeff_post,0 , M[1,8]
 
mat ci_low = [M[1,5] - 1.96*sqrt(V[5,5]), M[1,6] - 1.96*sqrt(V[6,6]),   M[1,7] - 1.96*sqrt(V[7,7]), 0, M[1,8] - 1.96*sqrt(V[8,8])]
mat ci_high = [M[1,5] + 1.96*sqrt(V[5,5]), M[1,6] + 1.96*sqrt(V[6,6]),  M[1,7] + 1.96*sqrt(V[7,7]), 0, M[1,8] + 1.96*sqrt(V[8,8])]


mat coeff = coeff\ T
mat coeff  = coeff'
mat coeff_post = coeff_post\ T
mat coeff_post  = coeff_post'
mat coeff_post_ci_low = ci_low\T
mat coeff_post_ci_low = coeff_post_ci_low'

mat coeff_post_ci_high = ci_high\T
mat coeff_post_ci_high = coeff_post_ci_high'


matrix colnames coeff = mvar svar 
svmat coeff, names(col)

matrix colnames coeff_post = mvarpost svarpost 
svmat coeff_post, names(col)

matrix colnames coeff_post_ci_low = mvarpost_ci_low svarpost_ci_low 
svmat coeff_post_ci_low, names(col)

matrix colnames coeff_post_ci_high = mvarpost_ci_high svarpost_ci_high 
svmat coeff_post_ci_high, names(col)

set scheme sol
twoway rcap mvarpost_ci_low mvarpost_ci_high svarpost_ci_low, msize(large) lcolor(gs10)   /*
*/  ||  scatter mvarpost svarpost, msize(vlarge)  xlabel(-2 "-3" -1 "-2" 0 "-1" 1 "Election year" 2 "+1") msymbol(o) mcolor(gs3) /*
*/  || function y = 0 * x, range(svarpost) lcolor(black) lwidth(.2)  name(effect, replace) xtitle("") ytitle("Effect of the reform", size(large)) legend(off) 

twoway (connected mvar svar, msize(large) mcolor(black) lcolor(gs10)) ,  name(cycle, replace) xtitle("") ytitle("Budget cycle in investment", size(large)) legend(off)  /* 
*/ xlabel(-2 "-3" -1 "-2" 0 "-1" 1 "Election year" 2 "+1") 

graph combine cycle effect, cols(1) xcommon xsize(4)


graph export  ../../Results/Figures/Figure_5.png, replace
graph export  ../../Results/Figures/Figure_5.eps, replace



*** Figures 6 and 7 - Term limits and stability pact ****

*** TL ***
local pol_controls "non_ordinary vote_share1"   // remove TL from controls for the term-limit regressions

forv j = 0(1)1 {

capture drop mvar* svar*

areg  Spese_cc_pc $x1 $controls `pol_controls' i.year##i.region_code if term_limited == `j', cluster(id_towns) absorb(id_towns) 

mat M = e(b)
mat V = e(V)

matrix T = [-2,-1,0,1,2]

mat coeff = M[1,1..3]
mat coeff = coeff,0 , M[1,4]

mat coeff_post = M[1,5..7]
mat coeff_post = coeff_post,0 , M[1,8]

mat ci_low = [M[1,5] - 1.96*sqrt(V[5,5]), M[1,6] - 1.96*sqrt(V[6,6]),   M[1,7] - 1.96*sqrt(V[7,7]), 0, M[1,8] - 1.96*sqrt(V[8,8])]
mat ci_high = [M[1,5] + 1.96*sqrt(V[5,5]), M[1,6] + 1.96*sqrt(V[6,6]),  M[1,7] + 1.96*sqrt(V[7,7]), 0, M[1,8] + 1.96*sqrt(V[8,8])]

mat coeff = coeff\ T
mat coeff  = coeff'
mat coeff_post = coeff_post\ T
mat coeff_post  = coeff_post'
mat coeff_post_ci_low = ci_low\T
mat coeff_post_ci_low = coeff_post_ci_low'

mat coeff_post_ci_high = ci_high\T
mat coeff_post_ci_high = coeff_post_ci_high'


matrix colnames coeff = mvar svar 
svmat coeff, names(col)

matrix colnames coeff_post = mvarpost svarpost 
svmat coeff_post, names(col)

matrix colnames coeff_post_ci_low = mvarpost_ci_low svarpost_ci_low 
svmat coeff_post_ci_low, names(col)

matrix colnames coeff_post_ci_high = mvarpost_ci_high svarpost_ci_high 
svmat coeff_post_ci_high, names(col)

set scheme sol
twoway rcap mvarpost_ci_low mvarpost_ci_high svarpost_ci_low, msize(large) lcolor(gs10)  ylabel(-100(100)100)  /*
*/  ||  scatter mvarpost svarpost, msize(vlarge)  xlabel(-2 "-3" -1 "-2" 0 "-1" 1 "Election year" 2 "+1") msymbol(o) mcolor(gs3) /*
*/  || function y = 0 * x, range(svarpost) lcolor(black) lwidth(.2)  name(effect`j', replace) xtitle("") ytitle("Effect of the reform", size(large)) legend(off)  


if `j' == 0 {
twoway (connected mvar svar, msize(large) mcolor(black) lcolor(gs10)   ylabel(-100(100)200)) ,  name(cycle`j', replace) xtitle("") ytitle("Budget cycle in investment", size(large)) legend(off)  /* 
*/ xlabel(-2 "-3" -1 "-2" 0 "-1" 1 "Election year" 2 "+1") || function y = 0 * x, range(svarpost) lcolor(black) lwidth(.2) title("Not term-limited")
}

if `j' == 1 {
twoway (connected mvar svar, msize(large) mcolor(black) lcolor(gs10)   ylabel(-100(100)200)) ,  name(cycle`j', replace) xtitle("") ytitle("Budget cycle in investment", size(large)) legend(off)  /* 
*/ xlabel(-2 "-3" -1 "-2" 0 "-1" 1 "Election year" 2 "+1") || function y = 0 * x, range(svarpost) lcolor(black) lwidth(.2) title("Term-limited")

}

}
*

graph combine cycle0 cycle1 effect0  effect1, cols(2) xcommon ycommon xsize(6) 

graph export  ../../Results/Figures/Figure_6.png, replace
graph export  ../../Results/Figures/Figure_6.eps, replace


*** SP ***

forv j = 0(1)1 {

capture drop mvar* svar*

areg  Spese_cc_pc $x1 $controls $pol_controls   i.year##i.region_code if stability_pact == `j' & year >=2001 /*
*/  & population<=10000 , cluster(id_towns)  absorb(id_towns) // Restrict to municipalities close to 5,000 inhabitants thresholds

mat M = e(b)
mat V = e(V)

matrix T = [-2,-1,0,1,2]

mat coeff = M[1,1..3]
mat coeff = coeff,0 , M[1,4]

mat coeff_post = M[1,5..7]
mat coeff_post = coeff_post,0 , M[1,8]

mat ci_low = [M[1,5] - 1.96*sqrt(V[5,5]), M[1,6] - 1.96*sqrt(V[6,6]),   M[1,7] - 1.96*sqrt(V[7,7]), 0, M[1,8] - 1.96*sqrt(V[8,8])]
mat ci_high = [M[1,5] + 1.96*sqrt(V[5,5]), M[1,6] + 1.96*sqrt(V[6,6]),  M[1,7] + 1.96*sqrt(V[7,7]), 0, M[1,8] + 1.96*sqrt(V[8,8])]

mat coeff = coeff\ T
mat coeff  = coeff'
mat coeff_post = coeff_post\ T
mat coeff_post  = coeff_post'
mat coeff_post_ci_low = ci_low\T
mat coeff_post_ci_low = coeff_post_ci_low'

mat coeff_post_ci_high = ci_high\T
mat coeff_post_ci_high = coeff_post_ci_high'


matrix colnames coeff = mvar svar 
svmat coeff, names(col)

matrix colnames coeff_post = mvarpost svarpost 
svmat coeff_post, names(col)

matrix colnames coeff_post_ci_low = mvarpost_ci_low svarpost_ci_low 
svmat coeff_post_ci_low, names(col)

matrix colnames coeff_post_ci_high = mvarpost_ci_high svarpost_ci_high 
svmat coeff_post_ci_high, names(col)

set scheme sol

twoway rcap mvarpost_ci_low mvarpost_ci_high svarpost_ci_low, msize(large) lcolor(gs10)  ylabel(-100(100)100)  /*
*/  ||  scatter mvarpost svarpost, msize(vlarge)  xlabel(-2 "-3" -1 "-2" 0 "-1" 1 "Election year" 2 "+1") msymbol(o) mcolor(gs3) /*
*/  || function y = 0 * x, range(svarpost) lcolor(black) lwidth(.2)  name(effect`j', replace) xtitle("") ytitle("Effect of the reform", size(large)) legend(off) 

if `j' == 0 {
twoway (connected mvar svar, msize(large) mcolor(black) lcolor(gs10)   ylabel(-100(100)200)) ,  name(cycle`j', replace) xtitle("") ytitle("Budget cycle in investment", size(large)) legend(off)  /* 
*/ xlabel(-2 "-3" -1 "-2" 0 "-1" 1 "Election year" 2 "+1") || function y = 0 * x, range(svarpost) lcolor(black) lwidth(.2)   title("No Stability Pact")
}

if `j' == 1 {
twoway (connected mvar svar, msize(large) mcolor(black) lcolor(gs10)   ylabel(-100(100)200)) ,  name(cycle`j', replace) xtitle("") ytitle("Budget cycle in investment", size(large)) legend(off)  /* 
*/ xlabel(-2 "-3" -1 "-2" 0 "-1" 1 "Election year" 2 "+1") || function y = 0 * x, range(svarpost) lcolor(black) lwidth(.2)   title("Stability Pact")
}

}
*

graph combine cycle0 cycle1 effect0  effect1, cols(2) xcommon ycommon xsize(6) 

graph export  ../../Results/Figures/Figure_7.png, replace
graph export  ../../Results/Figures/Figure_7.eps, replace



