/*********************************************************************

* Disaggregated baseline results * 

- Table 2
- Table 15 (Appendix)

*********************************************************************/

clear
use ../../Data/Final/Data_final.dta, replace

do ../Auxiliary/Estimation_globals.do // Define global variables 


xtset id_towns year
set more off

* Some labelling *
label var years_minus2 "3 years bf. elect."
label var years_minus1 "2 years bf. elect."
label var years_0 "1 year bf. elect."
label var years_2 "1 year aft. elect."
label var years_f_minus2 "3 years bf. elect.*Post"
label var years_f_minus1 "2 years bf. elect.*Post"
label var years_f0 "1 year bf. elect.*Post"
label var years_f2 "1 year aft. elect.*Post"


**** Table 2 - Baseline results for disaggregated revenues ****

reg Entr_alienaz_pc Entr_prestiti_pc Entr_extra_pc Entr_servizi_pc Entr_trib_pc Entr_trasf_pc Totale_gen_entr_pc
gen non_missing = e(sample)  // Restrict sample to observations for which all revenue variables are non-missing 

eststo clear

foreach i of varlist Entr_alienaz_pc-Entr_trasf_pc Totale_gen_entr_pc {

eststo:  areg `i' $x1 $controls_panel $pol_controls i.year##i.region_code if non_missing == 1, cluster(id_towns) absorb(id_towns)

summ `i' if e(sample), mean
estadd scalar vmean = r(mean)
}
*

esttab using ../../Results/Tables/Table_2.tex, replace compress  keep($x1) /*
*/ label booktabs se(%3.2f)  sfmt(0)  r2(0) b(a2) /*
*/ star(* 0.10 ** 0.05 *** 0.01)  f gaps  nonotes /*
*/ s(vmean r2 N, label("Mean of dep. var." "\emph{R}$^2$  " "Obs.")) 


**** Table 15 (Appendix)  - Baseline results for disaggregated expenditures ****

reg Istruzione_cc_pc Polizia_cc_pc Amminist_cc_pc Viabilita_cc_pc Sviluppo_cc_pc Turismo_cc_pc Sociale_cc_pc Sport_cc_pc Servizi_cc_pc Cultura_cc_pc Giustizia_cc_pc Territorio_cc_pc
gen non_missing_e = e(sample)  // Restrict sample to observations for which all expenditure variables are non-missing 

eststo clear

foreach i of varlist Istruzione_cc_pc-Territorio_cc_pc{
eststo: areg `i' $x1 $controls_panel $pol_controls i.year##i.region_code if non_missing_e == 1, cluster(id_towns) absorb(id_towns)
summ `i' if e(sample), mean
estadd scalar vmean = r(mean)
}
*

esttab using ../../Results/Tables/Table_15.tex, replace compress se r2 keep($x1) /*
*/ label booktabs   se(%3.2f)  sfmt(0)  r2(0) b(a2)  star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes /*
*/ s(vmean r2 N, label("Mean of dep. var." "\emph{R}$^2$  " "Obs.")) 


