/*******************************************************************************

** Table 8 - Effect of spending on re-election probability of the incumbent **

*******************************************************************************/

clear all
set more off

use ../../Data/Final/Data_reelection.dta, replace
keep if winner_ran_again == 1  // Only keep terms in which the incumbent decided to run for re-election


** Table  8 - Effect of spending on re-election probability of the incumbent (conditional on running again) **

local controls "population pop2 pop3 surface density altitude capp non_ordinary"
local x "Totale_gen_spese Spese_corr_pc_last_year Spese_cc_pc_last_year Spese_prestiti_pc_last_year Spese_servizi_pc_last_year "


eststo clear

eststo: probit winner_won_again    `x'  `controls' _reg* if election_year_next <= 2007, cluster(id_towns)  // region effects
estadd margins, eyex(*) atmeans
estadd local controls "Y" , replace
estadd local region_d "Y" , replace
su winner_won_again if election_year_next <= 2007
estadd scalar vmean = r(mean)

eststo: probit winner_won_again    `x'  `controls' _reg* if election_year_next ==  2008, cluster(id_towns)  // region effects
estadd margins, eyex(*) atmeans
estadd local controls "Y" , replace
estadd local region_d "Y" , replace
su winner_won_again  if election_year_next ==  2008
estadd scalar vmean = r(mean)

eststo: probit winner_won_again    `x'  `controls' _reg* if election_year_next ==  2009, cluster(id_towns)  // region effects
estadd margins, eyex(*) atmeans
estadd local controls "Y" , replace
estadd local region_d "Y" , replace
su winner_won_again  if election_year_next ==  2009
estadd scalar vmean = r(mean)

eststo: probit winner_won_again    `x'  `controls' _reg* if election_year_next ==  2010, cluster(id_towns)  // region effects
estadd margins, eyex(*) atmeans
estadd local controls "Y" , replace
estadd local region_d "Y" , replace
su winner_won_again if election_year_next ==  2010
estadd scalar vmean = r(mean)

eststo: probit winner_won_again    `x'  `controls' _reg* if election_year_next ==  2011, cluster(id_towns)  // region effects
estadd margins, eyex(*) atmeans
estadd local controls "Y" , replace
estadd local region_d "Y" , replace
su winner_won_again if election_year_next ==  2011
estadd scalar vmean = r(mean)

label var winner_won_again " " 


esttab using ../../Results/Tables/Table_8.tex, replace  se(4) /*
*/ keep( Spese_corr_pc_last_year Spese_cc_pc_last_year Spese_prestiti_pc_last_year Spese_servizi_pc_last_year  Totale_gen_spese) /*
*/ order(vote_share1 Post Spese_corr_pc_last_year Spese_cc_pc_last_year Spese_prestiti_pc_last_year Spese_servizi_pc_last_year Totale_gen_spese)/*
*/ eqlabels(none)  collabels("\multicolumn{1}{c}{Elast./SE}") /*
*/ cells("margins_b(fmt(3)star)" "margins_se(fmt(3)par)") refcat(Spese_corr_pc_last_year "\emph{Exp. in pre-election year}" Totale_gen_spese "\emph{Expenditures over term}", nolabel)   /*
*/ nomtitles  label booktabs  star(* 0.10 ** 0.05 *** 0.01)  f gaps  nonotes/*
*/ s(vmean controls  region_d r2_p N, fmt(2 0 0 2 0) label("Mean of dep. var" "Controls"  "Region Effects"  "\emph{Pseudo-R}$^2$  " "Obs.")) /*
*/ alignment(c)   b(4) mgroups("<=2007" "2008" "2009" "2010" "2011",pattern(1 1 1 1 1)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 

