/***********************************************************

* Estimation results - Sample splits  *

-   Table 16 (Appendix) - Tabulate above/below median for each region ***** 
-   Table 3 - Baseline sample splits based on newspaper sales only *****
-   Tables 4 through 7 - Sample splits tables based on newspaper sales AND each of the variables ***

***********************************************************/


clear 
use ../../Data/Final/Data_final.dta, replace
do ../Auxiliary/Estimation_globals.do // Define global variables 

xtset id_towns year
set more off

label var Spese_cc_pc "Invest. exp."


**** Table 16 (Appendix) - Tabulate above/below median for each region ***** 

preserve
eststo clear

* Generate the (national level) median of newspaper variable *

egen median_copies_local_p= pctile(copies_local_p) if year == 2007   				// Generate 2007 OVERALL (national level) median. This definition is only used to do this tabulation below. 
gen copies_local_p_2007x = copies_local_p  if year == 2007							// Generate the 2007 value for each municipality

bys id_towns: egen  median_copies_local_p_2007 = max(median_copies_local_p) if copies_local_p != .
bys id_towns: egen  copies_local_p_2007 = max(copies_local_p_2007x) if copies_local_p != .

capture drop media mediax

gen mediax = (copies_local_p_2007 >median_copies_local_p_2007) if copies_local_p_2007!=. 
bys id_towns: egen  above_median_copies_local_p = max(mediax)

drop median_copies_local_p  copies_local_p_2007x 

capture label drop lll

label define lll 0 "< median" 1 "> median"
label values above_median_copies_local_p lll  

estpost tab region_code above_median_copies_local_p

esttab  using ../../Results/Tables/Table_16.tex , replace cell(b(fmt(0)))  ///
collabels(none) unstack noobs nonumber  eqlabels(, lhs("") ) 

restore



***** Table 3 - Baseline sample splits based on newspaper sales only *****

**** Generate the median of newspaper variable ****

bys region_code: egen median_copies_local_p= pctile(copies_local_p) if year == 2007   	// Generate 2007 overall median *for each region* - used in the paper 

gen copies_local_p_2007x = copies_local_p  if year == 2007							// Generate the 2007 value for each municipality

bys id_towns: egen  median_copies_local_p_2007 = max(median_copies_local_p) if copies_local_p != .
bys id_towns: egen  copies_local_p_2007 = max(copies_local_p_2007x) if copies_local_p != .

capture drop media mediax

gen mediax = (copies_local_p_2007 >median_copies_local_p_2007) if copies_local_p_2007!=. 
bys id_towns: egen  above_median_copies_local_p = max(mediax)

drop median_copies_local_p  copies_local_p_2007x 



eststo clear

eststo A: areg  Spese_cc_pc $x1 $controls_panel $pol_controls  i.year##i.region_code i.region_macro##ib4.cycle##i.Post if above_median_copies_local_p == 1, cluster(id_towns) absorb(id_towns) 
* Note: allow north and south to differ in terms of the effect of the reform. Take the election year as reference year (ib4) *
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

eststo B: areg  Spese_cc_pc $x1 $controls_panel $pol_controls  i.year##i.region_code i.region_macro##ib4.cycle##i.Post if above_median_copies_local_p == 0, cluster(id_towns) absorb(id_towns) 
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

eststo D: areg  Entr_prestiti_pc $x1 $controls_panel $pol_controls  i.year##i.region_code i.region_macro##ib4.cycle##i.Post if above_median_copies_local_p == 1, cluster(id_towns) absorb(id_towns) 
summ Entr_prestiti_pc if e(sample)
estadd scalar vmean = r(mean)

eststo E: areg  Entr_prestiti_pc $x1 $controls_panel $pol_controls  i.year##i.region_code i.region_macro##ib4.cycle##i.Post if above_median_copies_local_p == 0, cluster(id_towns) absorb(id_towns) 
summ Entr_prestiti_pc if e(sample)
estadd scalar vmean = r(mean)

** Table 3 **
esttab using ../../Results/Tables/Table_3.tex, replace  se(%3.2f) r2 /*
*/ keep($x1) label  booktabs star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes/*
*/ s(vmean r2 N, label("Mean of dep. var." "\emph{R}$^2$  " "Obs.")) /* 
*/ mtitles("\specialcell{Local sales \\ > median}" "\specialcell{Local sales \\ < median}" "\specialcell{Local sales \\ > median}" "\specialcell{Local sales \\ < median}") /* 
*/ alignment(c) sfmt(0) r2(0) b(a2) mgroups("Investment expenditures" "Borrowing",pattern(1 0 1 0)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 



**** Tables 4-7 - Sample splits tables based on newspaper sales AND each of the variables ***


label var c_ethnic "Foreign \\ residents"
label var c_educ "College \\ educated"
label var c_associations_pc "NGOs p.c."
label var turnout "Turnout"


**** Generate the median of the other variables ****

local table_num = 4

foreach j of varlist c_associations_pc c_educ c_ethnic  turnout {

local lab: variable label `j '  /* <- save variable label in local `lab' (for the table headers) */

* Generate the median variable (Variable > median in 2007) *
bys region_code: egen median_`j'= pctile(`j') if year == 2007   // Generate 2007 overall median *for each region*  

gen `j'_2007x = `j'  if year == 2007							// Generate the 2007 value for each municipality

bys id_towns: egen  median_`j'_2007 = max(median_`j') if `j' != .
bys id_towns: egen  `j'_2007 = max(`j'_2007x) if `j' != .

capture drop mediax

gen mediax = (`j'_2007 >median_`j'_2007) if `j'_2007!=. // Use the dummy
bys id_towns: egen  above_median_`j' = max(mediax)

drop median_`j'  `j'_2007x 


*** Tables 4-7 - Sample splits tables based on newspaper sales AND each of the variables  ***

eststo clear

eststo A: areg  Spese_cc_pc $x1 $controls_panel $pol_controls  i.year##i.region_code i.region_macro##ib4.cycle##i.Post /*
*/ if above_median_copies_local_p == 1 & above_median_`j' == 1, cluster(id_towns) absorb(id_towns) 
* Note: allow north and south to differ in terms of the effect of the reform. Take the election year as reference year (ib4) *
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

eststo B: areg  Spese_cc_pc $x1 $controls_panel $pol_controls  i.year##i.region_code i.region_macro##ib4.cycle##i.Post /*
*/  if above_median_copies_local_p == 1 & above_median_`j' == 0, cluster(id_towns) absorb(id_towns) 
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

eststo C: areg  Spese_cc_pc $x1 $controls_panel $pol_controls  i.year##i.region_code i.region_macro##ib4.cycle##i.Post /*
*/ if above_median_copies_local_p == 0 & above_median_`j' == 1, cluster(id_towns) absorb(id_towns) 
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

eststo D: areg  Spese_cc_pc $x1 $controls_panel $pol_controls  i.year##i.region_code i.region_macro##ib4.cycle##i.Post /*
*/ if above_median_copies_local_p == 0 & above_median_`j' == 0, cluster(id_towns) absorb(id_towns) 


summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)


* Split-sample tables *
esttab using ../../Results/Tables/Table_`table_num'.tex, replace  se(%3.2f) r2 /*
*/ keep($x1) /*
*/ label  booktabs star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes/*
*/ s(vmean r2 N, label("Mean of dep. var." "\emph{R}$^2$  " "Obs.")) /* 
*/ mtitles("\specialcell{`lab' \\ > median}" "\specialcell{`lab' \\ < median}" "\specialcell{`lab' \\ > median}" "\specialcell{`lab' \\ < median}") /* 
*/ alignment(c) sfmt(0) r2(0) b(a2) mgroups("\specialcell{Local sales \\ > median}" "\specialcell{Local sales \\ < median}",pattern(1 0 1 0)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 

local table_num = `table_num' +1

}
*



