/**************************************************************************

* Robustness checks - instrumenting the budget cycle *

-   Table 17 and 18 (Appendix) - Tabulate above/below median for each region  

**************************************************************************/



clear all
use ../../Data/Final/Data_final.dta, replace

do ../Auxiliary/Estimation_globals.do // Define global variables 


xtset id_towns year
set more off
set matsize 10000

local controls_panel "male age education Education_current_pc population pop2 density"  // For some reason xtivreg2 doesn't like pop3 so I remove it here


* Column I  using "Exogenous" election dates directly *
eststo A:  qui:  areg  Spese_cc_pc years_minus2t years_minus1t years_0t  years_2t years_f_minus2t years_f_minus1t years_f0t years_f2t/*
*/ `controls_panel' $pol_controls i.year##i.region_code, cluster(id_towns) absorb(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace

* Column II  using "Exogenous" election dates as an IV for true dates
tab year, gen(year)

eststo B: xi: xtivreg2  Spese_cc_pc (years_minus2 years_minus1 years_0  years_2  years_f_minus2 years_f_minus1 years_f0 years_f2 = /*
*/ years_minus2t years_minus1t years_0t  years_2t  years_f_minus2t years_f_minus1t years_f0t years_f2t) i.year*i.region_code /*
*/ `controls_panel' $pol_controls , first fe cluster(id_towns)
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace


* Table 18 (Appendix) *
esttab A B using  ../../Results/Tables/Table_18.tex, replace compress se r2(2)  /*
*/ keep(years_minus2 years_minus1 years_0 years_2 years_f_minus2 years_f_minus1  years_f0 years_f2 ) /*
*/ rename(years_minus2t years_minus2  years_minus1t years_minus1 years_0t years_0  years_2t  years_2  years_f_minus2t  /*
*/ years_f_minus2  years_f_minus1t years_f_minus1  years_f0t  years_f0  years_f2t years_f2 /*
*/ years_f_minus2_alt years_f_minus2 years_f_minus1_alt years_f_minus1 years_f0_alt years_f0 years_f2_alt years_f2)    /*
*/ label  mtitles( "As regressors" "As IV" ) /*
*/ star(* 0.10 ** 0.05 *** 0.01) f booktabs gaps  nonotes alignment(c) sfmt(0)  b(a2) /*
*/ s(controls year_d year_r fixed r2 N, fmt(0 0 0 0 2 0) label("Controls" "Year Effects" "Year-Region Effects" "Municipality Effects" "\emph{R}$^2$  " "Obs.")) /*
*/ mgroups("Using exogenous elections" ,pattern(1  0  )  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  


* Table 17 (Appendix): First-stages of the IV regressions *
eststo clear

eststo: xi: xtivreg2  Spese_cc_pc (years_minus2 years_minus1 years_0  years_2  years_f_minus2 years_f_minus1 years_f0 years_f2 = /*
*/ years_minus2t years_minus1t years_0t  years_2t  years_f_minus2t years_f_minus1t years_f0t years_f2t) i.year*i.region_code    /*
*/ `controls_panel' $pol_controls , savefirst savefprefix(first) first fe cluster(id_towns)

label var years_minus2 "\specialcell{3 years bf. \\ election}"
label var years_minus1 "\specialcell{2 years bf. \\ election}"
label var years_0 "\specialcell{1 year bf. \\ election}"
label var years_2 "\specialcell{1 years aft. \\ election}"

label var years_f_minus2 "\specialcell{3 years bf. \\ *Post}"
label var years_f_minus1 "\specialcell{2 years bf. \\ *Post}"
label var years_f0 "\specialcell{1 year bf. \\ *Post}"
label var years_f2 "\specialcell{1 years aft. \\ *Post}"

esttab first* using  ../../Results/Tables/Table_17.tex,  replace compress t(1)  f booktabs gaps  nonotes label /*
*/ keep(years_minus2t years_minus1t years_0t  years_2t  years_f_minus2t years_f_minus1t years_f0t years_f2t ) /*
*/ alignment(c) sfmt(0)  b(2) varlabels(years_minus2t "3 years bf.election (theor.)" years_minus1t /*
*/ "2 years bf.election (theor.)" years_0t "1 year bf.election (theor.)" years_2t  "1 years aft.election (theor.)" /*
*/ years_f_minus2t "3 years bf.*Post (theor.)" years_f_minus1t "2 years bf.*Post (theor.)" years_f0t "1 year bf.*Post (theor.)"/*
*/ years_f2t "1 year aft.*Post (theor.)")
