/****************************************************************************************
 
Table 19 - Excluding groups from estimation *

****************************************************************************************/

clear all
use ../../Data/Final/Data_final.dta, replace

xtset id_towns year
set more off
set matsize 1000

do ../Auxiliary/Estimation_globals.do // Define global variables 

gen group_elections = 0  // Towns with missing elections, or new ones (Baranzate, Gravedona ed uniti)

forv i = 1999(1)2003 {
gen gr`i' = anno if anno == `i'
bys town: egen group_`i' = max(gr`i')
replace group_elections = group_`i' if  group_`i' !=. & group_elections == 0
}
*

drop if group_elections == 0 

eststo clear 

forv i = 1999(1)2003 {  // Drop one year at a tome

eststo :  qui:  areg  Spese_cc_pc $x1  $controls_panel $pol_controls i.year##i.region_code if group_election != `i', cluster(id_towns) absorb(id_towns) 
estadd local year_d "Y" , replace
estadd local year_r "Y" , replace
estadd local fixed "Y" , replace
estadd local controls "Y" , replace
summ Spese_cc_pc if e(sample)
estadd scalar vmean = r(mean)

}
*


* Table 19 *
esttab using ../../Results/Tables/Table_19.tex, replace compress se r2(2) /*
*/ keep(years_minus2 years_minus1 years_0  years_2  years_f_minus2 years_f_minus1 years_f0 years_f2 ) /*
*/ label booktabs  star(* 0.10 ** 0.05 *** 0.01)  f nogaps nonum nonotes mtitles("Drop 1999" "Drop 2000" "Drop 2001" "Drop 2002" "Drop 2003" )/*
*/ s(vmean controls year_d year_r fixed r2 N, label("Mean of dep. var" "Controls" "Year Effects" "Year-Region Effects" "Municipality Effects" "\emph{R}$^2$  " "Obs.")) /*
*/ alignment(c)  b(a2) 
